Array (imandrax-ocaml.Imandrax_ocaml_prelude.Prelude_extracted.Array)

### Arrays

Program mode only

A program-mode imperative array, that can be mutated

`include module type of struct include Stdlib.Array end`
`type !'a t = 'a array`
`val create_float : int -> float array`
`val make_matrix : int -> int -> 'a -> 'a array array`
`val init_matrix : int -> int -> (int -> int -> 'a) -> 'a array array`
`val append : 'a array -> 'a array -> 'a array`
`val concat : 'a array list -> 'a array`
`val copy : 'a array -> 'a array`
`val to_list : 'a array -> 'a list`
`val of_list : 'a list -> 'a array`
`val iter : ('a -> unit) -> 'a array -> unit`
`val map : ('a -> 'b) -> 'a array -> 'b array`
`val map_inplace : ('a -> 'a) -> 'a array -> unit`
`val mapi_inplace : (int -> 'a -> 'a) -> 'a array -> unit`
`val fold_left : ('acc -> 'a -> 'acc) -> 'acc -> 'a array -> 'acc`
`val fold_left_map : ('acc -> 'a -> 'acc * 'b) -> 'acc -> 'a array -> 'acc * 'b array`
`val fold_right : ('a -> 'acc -> 'acc) -> 'a array -> 'acc -> 'acc`
`val iter2 : ('a -> 'b -> unit) -> 'a array -> 'b array -> unit`
`val map2 : ('a -> 'b -> 'c) -> 'a array -> 'b array -> 'c array`
`val for_all : ('a -> bool) -> 'a array -> bool`
`val exists : ('a -> bool) -> 'a array -> bool`
`val for_all2 : ('a -> 'b -> bool) -> 'a array -> 'b array -> bool`
`val exists2 : ('a -> 'b -> bool) -> 'a array -> 'b array -> bool`
`val mem : 'a -> 'a array -> bool`
`val memq : 'a -> 'a array -> bool`
`val find_opt : ('a -> bool) -> 'a array -> 'a option`
`val find_index : ('a -> bool) -> 'a array -> int option`
`val find_map : ('a -> 'b option) -> 'a array -> 'b option`
`val find_mapi : (int -> 'a -> 'b option) -> 'a array -> 'b option`
`val split : ('a * 'b) array -> 'a array * 'b array`
`val combine : 'a array -> 'b array -> ('a * 'b) array`
`val sort : ('a -> 'a -> int) -> 'a array -> unit`
`val stable_sort : ('a -> 'a -> int) -> 'a array -> unit`
`val fast_sort : ('a -> 'a -> int) -> 'a array -> unit`
`val shuffle : rand:(int -> int) -> 'a array -> unit`
`val to_seq : 'a array -> 'a Stdlib.Seq.t`
`val to_seqi : 'a array -> (int * 'a) Stdlib.Seq.t`
`val of_seq : 'a Stdlib.Seq.t -> 'a array`
`val unsafe_get : 'a array -> int -> 'a`
`val unsafe_set : 'a array -> int -> 'a -> unit`
`module Floatarray : sig ... end`
`val get : 'a array -> Imandrax_util.Z.t -> 'a`
`val set : 'a array -> Imandrax_util.Z.t -> 'a -> unit`
`val make : Imandrax_util.Z.t -> 'a -> 'a array`
`val init : Imandrax_util.Z.t -> (Imandrax_util.Z.t -> 'a) -> 'a array`
`val sub : 'a array -> Imandrax_util.Z.t -> Imandrax_util.Z.t -> 'a array`
`val length : 'a array -> Imandrax_util.Z.t`
`val mapi : (Imandrax_util.Z.t -> 'a -> 'b) -> 'a array -> 'b array`
`val iteri : (Imandrax_util.Z.t -> 'a -> unit) -> 'a array -> unit`
`val fill : 'a array -> Imandrax_util.Z.t -> Imandrax_util.Z.t -> 'a -> unit`
`val blit : 'a array -> Imandrax_util.Z.t -> 'a array -> Imandrax_util.Z.t -> Imandrax_util.Z.t -> unit`